/***********************************************************************
 * Program: DBInit.java
 * Purpose: Initializes the database tables.
 **********************************************************************/
package installation;
import java.awt.*;
import java.awt.event.*;
import java.sql.*;
import java.io.*;

public class DBInit extends Frame implements ActionListener{
  
  Panel p1,p2,p3,p4,p5;
  Label l1,l2,l3;
  Checkbox[] cb; 
  Button b1,b2;
  MultiLineLabel ml1;
  RandomAccessFile f;
  TextArea t1;
  
  Statement s;
  Connection conn;

  String[] sql=new String[3];
  String configFile="configure.txt";

  String DRIVER;
  String server;
  String image;
  String USER;
  String PASS;
  String CONNECT;
  String contact;
  String con_name;

  String message1="The following SQL scripts are used to set up the \n";
  String message2="Training Management Database.  Remove the check \n";
  String message3="if you do not want the script to be executed.\n";
  String message4="Please make sure that the configuration file has the \n";
  String message5="correct properties";
  
  String message=message1+message2+message3+message4+message5;

  public DBInit() {
    //Assign script names to sql[].
    sql[0]="tables.sql";
    sql[1]="sequences.sql";
    sql[2]="admin.sql";

    //Read the configure.txt file for parameters.
    readConfig();

    //Set up the interface.
    initGUI();

    //Source oracle's cshrc file externally.
    initTables();
  }
  
  public void initTables(){
    try {
      String command="source_script";
      Process p = Runtime.getRuntime().exec(command);
      p.waitFor();
    }
    catch (Exception e) {
      System.out.println("Error: "+e.toString());
    }

    //Load the driver and connect to it.
    try{
      Class.forName(DRIVER);
      conn=DriverManager.getConnection(CONNECT,USER,PASS);
    }
    catch(ClassNotFoundException e){
      System.out.println("Couldn't load database driver"+e.getMessage());
    }
    catch(SQLException e){
      System.out.println("Couldn't load data base driver");
      System.out.println(e);
    }

  }
  
  public void readConfig(){
    //Reads the configuration file configure.txt and assigns the
    //necessary values to string variables.
    try{
      f=new RandomAccessFile(configFile,"r");
      String line=f.readLine();
      while(line!=null){
	if(line.equals("JdbcDriver:"))
	  DRIVER=f.readLine();
	else if(line.equals("ServerURLBase:"))
	  server=f.readLine();
	else if(line.equals("ImageBase:"))
	  image=f.readLine();
	else if(line.equals("DBName:"))
	  USER=f.readLine();
	else if(line.equals("DBPassword:"))
	  PASS=f.readLine();
	else if(line.equals("ConnectString:"))
	  CONNECT=f.readLine();
	else if(line.equals("ContactEmail:"))
	  contact=f.readLine();
	else if(line.equals("ContactName:"))
	  con_name=f.readLine();
	line=f.readLine();
      }
      f.close();
    }
    catch(IOException e) {
      System.out.println(e);
    }
  }

  public void doTable(String sql){
    //Reads the sql files.  Since the commands are spread out over 
    //several lines, each command must first be concatenated up to
    //the ending semicolon.  The execute() command does not understand
    //this ending semicolon, so it is removed.
    boolean status;
    try{
      f=new RandomAccessFile(sql,"r");
      s=conn.createStatement();
      String line=f.readLine();
      String oldString="";
      while(line!=null){
	//System.out.println(line);
	if(!((line.trim()).endsWith(";"))) {
	  oldString+=line;
	}
	else {
	  oldString+=line;
	  int itemp=oldString.lastIndexOf(";");
	  String stemp=oldString.substring(0,itemp);
	  //	  System.out.println(stemp.trim());
	  status=s.execute(stemp);
	  oldString="";
	}
	line=f.readLine();	  
      }
      f.close();
    }
    catch(IOException e){
      System.out.println(e);
    }
    catch(SQLException e){
      System.out.println(e);
    }
    
  }
  
  public void initGUI(){
    //This method sets up the display.
    
    setLayout(new GridLayout(3,1));

    p1=new Panel();
    ml1=new MultiLineLabel(message,10,10);
    p1.add(ml1);
    add(p1);

    p2=new Panel();
    cb=new Checkbox[3];
    cb[0]=new Checkbox(sql[0],true);
    cb[1]=new Checkbox(sql[1],true);
    cb[2]=new Checkbox(sql[2],true);

    p4=new Panel();
    p4.setLayout(new BorderLayout());

    p2.add(cb[0]);
    p2.add(cb[1]);
    p2.add(cb[2]);
    p4.add("North",p2);

    p5=new Panel();
    t1=new TextArea();
    t1.setEditable(false);
    p5.add(new Label("Executed scripts"));
    p4.add("Center",t1);
    p4.add("South",p5);
    add(p4);

    p3=new Panel();
    b1=new Button("Submit");
    b2=new Button("Close Window");
    b1.addActionListener(this);
    b2.addActionListener(this);
    p3.add(b1);
    p3.add(b2);
    add(p3);
  }

  public void actionPerformed(ActionEvent event) {
    Object source=event.getSource();
    if(source==b1) {
      for(int i=0;i<3;i++) {
	if(cb[i].getState()) {
	  //	  System.out.println("Execute commands in "+sql[i]);
	  t1.append("Executing commands in "+sql[i]+"\n");
	  doTable(sql[i]);
	}
      }
      t1.append("Finished\n");
    }
    else if(source==b2) {
      this.dispose();
    }
    
  }
  
  public static void main(String[] args) {
    DBInit f=new DBInit();
    f.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {System.exit(0);}
    });
    f.pack();
    f.show();
  }

}

      /* Sum stuff that worked in tests.
      System.out.println("SQL command executing");
      s=conn.createStatement();
      status=s.execute("drop table addresses");
      System.out.println("Table dropped");
      String s1="create table addresses (";
      String s2="id varchar2(50),address varchar2(50))";
      //      String s1="create table addresses (";
      status=s.execute(s1+s2);
      System.out.println("Table created");
      */
