/***********************************************************************
 * Program: Install.java
 * Purpose: A controller program to run the other installation scripts
 * in this package.  Another class, EntryThread, follows this file.
 * The Entry window is run on a separate thread so that I can open and
 * close this window before showing Install's menu window.
 ***********************************************************************/
package installation;
import java.awt.*;
import java.awt.event.*;

public class Install extends Frame implements ActionListener{
  ConfigEdit ce;
  DBInit db;
  Entry entry=new Entry(this);
  static boolean wait=true;
  Panel p1,p2,p3;
  Button b1,b2,b3;
  MultiLineLabel mll;
  private ExitDialog ed=null;
  
  String message11="Welcome to the Training Management Database Installation\n";
  String message12="Script.  Please make sure that you have installed the\n";
  String message13="Web Server on your database server.  You should also\n";
  String message14="run this script only on the machine that will act as the server.";

  String message1=message11+message12+message13+message14;
  String message2="Set configuration parameters.";
  String message3="Create the database tables and sequences.";

  public Install() {

    setLayout(new GridLayout(3,1));
    p1=new Panel();
    add(p1);
    mll=new MultiLineLabel(message1,10,10);
    p1.add(mll);

    p2=new Panel();
    p2.setLayout(new GridLayout(2,1,10,10));
    add(p2);
    b1=new Button("Edit the configuration parameters");
    b2=new Button("Create the database tables");
    b1.addActionListener(this);
    b2.addActionListener(this);
    p2.add(b1);
    p2.add(b2);

    p3=new Panel();
    add(p3);
    b3=new Button("Exit");
    b3.addActionListener(this);
    p3.add(b3);
  }    
  
  public void actionPerformed(ActionEvent e) {
    Object source=e.getSource();
    if(source==b1) {
      ce=new ConfigEdit();
      ce.addWindowListener(new WindowAdapter(){
      public void windowClosing(WindowEvent e) {System.exit(0);}});
      ce.setSize(400,600);
      ce.show();
    }
    else if(source==b2) {
      db=new DBInit();
      db.addWindowListener(new WindowAdapter(){
	public void windowClosing(WindowEvent e) {System.exit(0);}});
      db.pack();
      db.show();
    }
    else if(source==b3) {
      if(ed==null) {
	ed=new ExitDialog(this,"Gentle Reminder");
      }
      ed.show();
      this.dispose();
      System.exit(1);
    }
  }
  
  public void notify(Entry e){
    wait=false;
  }
  
  public static void main(String[] args) throws InterruptedException {
    Install f=new Install();
    Entry e=new Entry(f);
    EntryThread et=new EntryThread(e);
    
    et.start();
    while(wait) {
      et.run();
    }
    et.stop();

    f.addWindowListener(new WindowAdapter(){
      public void windowClosing(WindowEvent e) {System.exit(0);}});
    f.setTitle("TMD Installation");
    
    f.pack();
    f.show();
  }
}

class EntryThread extends Thread {
  Entry e;
  public EntryThread(Entry e){
    super();
    this.e=e;
  }
  public void start() {
    e.pack();
  }
  public void run() {
    e.show();
    try{
      sleep(1000);
    }
    catch(InterruptedException e) {}
  }
}
